==> universal_io-0.1.0.tar.gz: lib/src/io_driver/io_driver_vm.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:universal_io/io.dart';

import 'io_driver_browser.dart' show ZoneLocal, PlatformInfo;

class IODriver {
  static final ZoneLocal<IODriver> zoneLocal =
      new ZoneLocal<IODriver>(defaultValue: new IODriver());

  static IODriver get current {
    return zoneLocal.current;
  }

  final PlatformInfo platformInfo;

  IODriver({this.platformInfo = const PlatformInfo()});

  bool get isWatchSupported => throw new UnimplementedError();

  Stdout get stderr {
    throw new UnimplementedError();
  }

  Stdin get stdin {
    throw new UnimplementedError();
  }

  Stdout get stdout {
    throw new UnimplementedError();
  }

  Directory get systemTemp {
    throw new UnimplementedError();
  }

  Future<RawDatagramSocket> bindRawDatagramSocket(host, int port,
      {bool reuseAddress: true, bool reusePort = false, int ttl = 1}) {
    throw new UnimplementedError();
  }

  Future<RawServerSocket> bindRawServerSocket(address, int port,
      {int backlog: 0, bool v6Only = false, bool shared = false}) {
    throw new UnimplementedError();
  }

  Future<ServerSocket> bindServerSocket(address, int port,
      {int backlog: 0, bool v6Only = false, bool shared = false}) {
    throw new UnimplementedError();
  }

  Future<RawSocket> connectRawSocket(host, int port,
      {sourceAddress, Duration timeout}) {
    throw new UnimplementedError();
  }

  Future<Socket> connectSocket(host, int port,
      {sourceAddress, Duration timeout}) {
    throw new UnimplementedError();
  }

  Future<List<NetworkInterface>> listNetworkInterfaces(
      {bool includeLoopback: false,
      bool includeLinkLocal: false,
      InternetAddressType type = InternetAddressType.any}) {
    throw new UnimplementedError();
  }

  Future<List<InternetAddress>> lookupInternetAddresses(String host,
      {InternetAddressType type = InternetAddressType.any}) {
    throw new UnimplementedError();
  }

  Directory newDirectory(String path) {
    throw new UnimplementedError();
  }

  File newFile(String path) {
    throw new UnimplementedError();
  }

  FileSystemEntity newFileSystemEntity(String path) {
    throw new UnimplementedError();
  }

  InternetAddress newInternetAddress(String value) {
    throw new UnimplementedError();
  }

  Link newLink(String path) {
    throw new UnimplementedError();
  }

  Future<InternetAddress> reverseLookupInternetAddress(
      InternetAddress address) {
    throw new UnimplementedError();
  }

  Future<ProcessResult> run(String executable, List<String> arguments,
      {String workingDirectory,
      Map<String, String> environment,
      bool includeParentEnvironment = true,
      bool runInShell = false,
      Encoding stdoutEncoding = systemEncoding,
      Encoding stderrEncoding = systemEncoding}) {
    throw new UnimplementedError();
  }

  ProcessResult runSync(String executable, List<String> arguments,
      {String workingDirectory,
      Map<String, String> environment,
      bool includeParentEnvironment = true,
      bool runInShell = false,
      Encoding stdoutEncoding = systemEncoding,
      Encoding stderrEncoding = systemEncoding}) {
    throw new UnimplementedError();
  }

  Future<Process> start(String executable, List<String> arguments,
      {String workingDirectory,
      Map<String, String> environment,
      bool includeParentEnvironment = true,
      bool runInShell = false,
      ProcessStartMode mode = ProcessStartMode.normal}) {
    throw new UnimplementedError();
  }

  Future<ConnectionTask<RawSocket>> startConnectRawSocket(host, int port,
      {sourceAddress}) {
    throw new UnimplementedError();
  }

  Future<ConnectionTask<Socket>> startConnectSocket(host, int port,
      {sourceAddress}) {
    throw new UnimplementedError();
  }
}

==> universal_io-0.1.1.tar.gz: lib/src/io_driver/io_driver_vm.dart <==
/// -----------------------------------------------------------------------------
/// Q: Why do we have this?
/// A: It's necessary to avoid conflicts between 'dart:io' and 'universal_io'.
///
/// This file does not actually do anything.
/// We just need to have the types.
/// -----------------------------------------------------------------------------
import 'dart:async';
import 'dart:convert';

import 'package:universal_io/io.dart';

import 'io_driver_browser.dart' show ZoneLocal, PlatformInfo;

class IODriver {
  static final ZoneLocal<IODriver> zoneLocal =
      ZoneLocal<IODriver>(defaultValue: IODriver());

  static IODriver get current {
    return zoneLocal.current;
  }

  final PlatformInfo platformInfo;

  IODriver({this.platformInfo = const PlatformInfo()});

  bool get isWatchSupported => throw UnimplementedError();

  Stdout get stderr {
    throw UnimplementedError();
  }

  Stdin get stdin {
    throw UnimplementedError();
  }

  Stdout get stdout {
    throw UnimplementedError();
  }

  Directory get systemTemp {
    throw UnimplementedError();
  }

  Future<RawDatagramSocket> bindRawDatagramSocket(host, int port,
      {bool reuseAddress = true, bool reusePort = false, int ttl = 1}) {
    throw UnimplementedError();
  }

  Future<RawServerSocket> bindRawServerSocket(address, int port,
      {int backlog = 0, bool v6Only = false, bool shared = false}) {
    throw UnimplementedError();
  }

  Future<ServerSocket> bindServerSocket(address, int port,
      {int backlog = 0, bool v6Only = false, bool shared = false}) {
    throw UnimplementedError();
  }

  Future<RawSocket> connectRawSocket(host, int port,
      {sourceAddress, Duration timeout}) {
    throw UnimplementedError();
  }

  Future<Socket> connectSocket(host, int port,
      {sourceAddress, Duration timeout}) {
    throw UnimplementedError();
  }

  Future<List<NetworkInterface>> listNetworkInterfaces(
      {bool includeLoopback = false,
      bool includeLinkLocal = false,
      InternetAddressType type = InternetAddressType.any}) {
    throw UnimplementedError();
  }

  Future<List<InternetAddress>> lookupInternetAddresses(String host,
      {InternetAddressType type = InternetAddressType.any}) {
    throw UnimplementedError();
  }

  Directory newDirectory(String path) {
    throw UnimplementedError();
  }

  File newFile(String path) {
    throw UnimplementedError();
  }

  FileSystemEntity newFileSystemEntity(String path) {
    throw UnimplementedError();
  }

  InternetAddress newInternetAddress(String value) {
    throw UnimplementedError();
  }

  Link newLink(String path) {
    throw UnimplementedError();
  }

  Future<InternetAddress> reverseLookupInternetAddress(
      InternetAddress address) {
    throw UnimplementedError();
  }

  Future<ProcessResult> run(String executable, List<String> arguments,
      {String workingDirectory,
      Map<String, String> environment,
      bool includeParentEnvironment = true,
      bool runInShell = false,
      Encoding stdoutEncoding = systemEncoding,
      Encoding stderrEncoding = systemEncoding}) {
    throw UnimplementedError();
  }

  ProcessResult runSync(String executable, List<String> arguments,
      {String workingDirectory,
      Map<String, String> environment,
      bool includeParentEnvironment = true,
      bool runInShell = false,
      Encoding stdoutEncoding = systemEncoding,
      Encoding stderrEncoding = systemEncoding}) {
    throw UnimplementedError();
  }

  Future<Process> start(String executable, List<String> arguments,
      {String workingDirectory,
      Map<String, String> environment,
      bool includeParentEnvironment = true,
      bool runInShell = false,
      ProcessStartMode mode = ProcessStartMode.normal}) {
    throw UnimplementedError();
  }

  Future<ConnectionTask<RawSocket>> startConnectRawSocket(host, int port,
      {sourceAddress}) {
    throw UnimplementedError();
  }

  Future<ConnectionTask<Socket>> startConnectSocket(host, int port,
      {sourceAddress}) {
    throw UnimplementedError();
  }
}
